Installation Guide — Bigplanet 2020 documentation

# Installation Guide

First you have to clone from the Github Repo. To do that just type in the command line:

    git clone https://github.com/VirtualPlanetaryLaboratory/bigplanet.git

Afterwards, go into the directory (bigplanet) and run the setup script:

    cd bigplanet
    python setup.py install

The setup script installs the various dependencies and allows bigplanet to be ran from the command line as well as be imported as a module.